@@ -29,6 +29,21 @@ class AlgorithmClient(BaseClient):
 
     #
 
+    def get_algorithm_from_context(self):
+        environment = self.get_environment_from_context()
+        if environment is None:
+            return None
+        return environment.get_algorithm()
+
+    def get_environment_from_context(self):
+        if not self.session.context or "algorithmEnvironmentId" not in self.session.context:
+            return None
+
+        environment_id = self.session.context.get("algorithmEnvironmentId")
+        return self.get_environment(environment_id)
+
+    #
+
     def list_algorithms(self):
         params = {"teamId": self.user["teamId"]}
         return self.session.request(
@@ -52,8 +67,7 @@ class AlgorithmClient(BaseClient):
     def invoke(self, algorithm_id, environment, problem, **kwargs):
         return self.session.invoke(algorithm_id, environment, problem, **kwargs)
 
-    def deploy(self, algorithm_id, environment, version, path, **kwargs):
+    def deploy(self, algorithm_id, environment, version, file_path, **kwargs):
         algorithm = self.get_algorithm(algorithm_id)
         environment = algorithm.get_environment(environment)
-        return environment.deploy(version, path, **kwargs)
-
+        return environment.deploy(version, file_path, **kwargs)
