@@ -103,7 +103,7 @@ class AlgorithmEnvironment(BaseResource):
 
     #
 
-    def deploy(self, version, path, **kwargs):
+    def deploy(self, version, file_path, **kwargs):
         description = kwargs.get("description", None)
         release_notes = kwargs.get("release_notes", None)
         increment = kwargs.get("increment", False)
@@ -117,15 +117,15 @@ class AlgorithmEnvironment(BaseResource):
                 new = VersionHelper.increment(latest)
                 version = str(new)
 
-        files = {"file": open(path, "rb")}
-        body = {
+        params = {
             "algorithmEnvironmentId": self.id,
             "version": version,
             "description": description,
             "releaseNotes": release_notes,
         }
+        files = {"file": open(file_path, "rb")}
         data = self.session.request(
-            "post", "release", "/api/Releases/upload", files=files, params=body
+            "post", "release", "/api/Releases/upload", files=files, params=params
         )
         return resources.AlgorithmRelease(data["id"], session=self.session, data=data)
 
@@ -146,6 +146,9 @@ class AlgorithmEnvironment(BaseResource):
 
     #
 
+    def get_mass_customization_unit(self, tag):
+        return resources.MetaUnit(self.id, tag, session=self.session)
+
     def list_mass_customization_units(self):
         params = {"algorithmEnvironmentId": self.id}
         return self.session.request(
